@@ -181,6 +181,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
         settings.zApplyGapBeforeButtonPixels();
         settings.zApplyAllowKeyboardEditing();
         settings.zApplyAllowEmptyDates();
+        settings.zApplyDisabledTextColor();
         // Draw the text field indicators, because they may not have been drawn if the initialDate
         // was null. (This is because the text would not have changed in that case.)
         // This should be called after the DatePickerSettings have been saved.
@@ -437,7 +438,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
         LocalDate parsedDate = InternalUtilities.getParsedDateOrNull(
                 text, settings.getFormatForDatesCommonEra(),
                 settings.getFormatForDatesBeforeCommonEra(),
-                settings.getFormatsForParsing(), settings.getLocale());
+                settings.getFormatsForParsing());
 
         // If the date could not be parsed, return false.
         if (parsedDate == null) {
@@ -568,7 +569,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
      * additional details.
      */
     public void setDateToToday() {
-        setDate(LocalDate.now());
+        setDate(LocalDate.now(settings.getClock()));
     }
 
     /**
@@ -880,7 +881,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
             parsedDate = InternalUtilities.getParsedDateOrNull(dateText,
                     settings.getFormatForDatesCommonEra(),
                     settings.getFormatForDatesBeforeCommonEra(),
-                    settings.getFormatsForParsing(), settings.getLocale());
+                    settings.getFormatsForParsing());
         }
         // If the date was parsed successfully, then check it against the veto policy.
         boolean dateIsVetoed = false;
@@ -973,8 +974,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
             // (Possibility: DisabledComponent)
             // Note: The date should always be validated (as if the component lost focus), before
             // the component is disabled.
-            dateTextField.setBackground(new Color(240, 240, 240));
-            dateTextField.setForeground(new Color(109, 109, 109));
+            dateTextField.setBackground(settings.getColor(DateArea.TextFieldBackgroundDisabled));
             dateTextField.setFont(settings.getFontValidDate());
             return;
         }
@@ -999,7 +999,7 @@ public class DatePicker extends JPanel implements CustomPopupCloseListener {
         LocalDate parsedDate = InternalUtilities.getParsedDateOrNull(dateText,
                 settings.getFormatForDatesCommonEra(),
                 settings.getFormatForDatesBeforeCommonEra(),
-                settings.getFormatsForParsing(), settings.getLocale());
+                settings.getFormatsForParsing());
         if (parsedDate == null) {
             // (Possibility: UnparsableValue)
             dateTextField.setBackground(settings.getColor(DateArea.TextFieldBackgroundInvalidDate));
