@@ -4,8 +4,6 @@ import java.awt.GridBagConstraints;
 import java.util.ArrayList;
 import java.util.Locale;
 import java.util.Properties;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 import com.github.lgooddatepicker.optionalusertools.DateVetoPolicy;
 import com.github.lgooddatepicker.optionalusertools.PickerUtilities;
 import com.github.lgooddatepicker.optionalusertools.TimeVetoPolicy;
@@ -20,19 +18,21 @@ import java.awt.Toolkit;
 import java.awt.Window;
 import java.io.DataInputStream;
 import java.io.InputStream;
+import java.text.ParsePosition;
 import java.time.LocalDate;
 import java.time.LocalTime;
 import java.time.chrono.IsoChronology;
 import java.time.format.DateTimeFormatter;
 import java.time.format.DateTimeFormatterBuilder;
 import java.time.format.FormatStyle;
+import java.time.temporal.ChronoField;
+import java.time.temporal.TemporalAccessor;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import javax.swing.DefaultCellEditor;
 import javax.swing.JTable;
-import javax.swing.UIDefaults;
 import javax.swing.table.TableCellEditor;
 
 /**
@@ -61,55 +61,45 @@ public class InternalUtilities {
         return (a == b) || (a != null && a.equals(b));
     }
 
-    /**
+/**
      * doesParsedDateMatchText, This compares the numbers in a parsed date, to the original text
      * from which the date was parsed. Specifically this compares the day of the month and the year
-     * of the parsed date to the text. On a technical note, this function is not aware of which
-     * field is which, but that ambiguity does not prevent it from performing a successful
-     * comparison on all tested cases. This will return true if the dates are a match, or otherwise
-     * return false.
+     * of the parsed date to the text. 
      *
-     * Testing note: This function has been thoroughly tested and gives the proper result with all
-     * valid and invalid dates in the years between -10000 and 10000 inclusive. Valid dates are
-     * defined as those dates that are returned from the LocalDate class, when using the
-     * localDate.plusDays(1) function. Invalid dates are defined as any of the following: The 31st
+     * Testing note: Invalid dates this function should detect are any of the following: The 31st
      * day of February, April, June, September, or November. The 30th day of February. Or the 29th
      * day of February on any year that is not a leap year.
      */
     static public boolean doesParsedDateMatchText(LocalDate parsedDate, String text,
-            Locale formatLocale) {
+            DateTimeFormatter usedFormatter) {
         if (parsedDate == null || text == null) {
             return false;
         }
-        text = text.toLowerCase();
-        // This only matches numbers, and it does not include any hyphen "-".
-        Pattern pattern = Pattern.compile("\\d+");
-        Matcher matcher = pattern.matcher(text);
-        ArrayList<String> unsignedNumbersFound = new ArrayList<String>();
-        while (matcher.find()) {
-            String foundString = matcher.group();
-            foundString = forceNumberStringToTwoDigits(foundString);
-            unsignedNumbersFound.add(foundString);
-        }
-        String parsedDayOfMonth = "" + parsedDate.getDayOfMonth();
-        parsedDayOfMonth = forceNumberStringToTwoDigits(parsedDayOfMonth);
-        boolean dayOfMonthFound = unsignedNumbersFound.remove(parsedDayOfMonth);
 
-        DateTimeFormatter formatBC = DateTimeFormatter.ofPattern("G", formatLocale);
-        String eraBCString = LocalDate.of(-100, 1, 1).format(formatBC).toLowerCase();
-        if (parsedDate.getYear() < 1 && text.contains(eraBCString)) {
-            String parsedYearForBC = "" + (parsedDate.getYear() - 1);
-            parsedYearForBC = parsedYearForBC.replace("-", "");
-            parsedYearForBC = forceNumberStringToTwoDigits(parsedYearForBC);
-            boolean yearFoundForBC = unsignedNumbersFound.remove(parsedYearForBC);
-            return yearFoundForBC && dayOfMonthFound;
-        } else {
-            String parsedYear = "" + parsedDate.getYear();
-            parsedYear = parsedYear.replace("-", "");
-            parsedYear = forceNumberStringToTwoDigits(parsedYear);
-            boolean yearFound = unsignedNumbersFound.remove(parsedYear);
-            return yearFound && dayOfMonthFound;
+        final TemporalAccessor parseResult = usedFormatter.parseUnresolved(text, new ParsePosition(0));
+
+        if (parseResult.isSupported(ChronoField.YEAR)) {
+            if (parseResult.get(ChronoField.YEAR) != parsedDate.get(ChronoField.YEAR)) {
+                return false;
+            }
         }
+        if (parseResult.isSupported(ChronoField.YEAR_OF_ERA)) {
+            if (parseResult.get(ChronoField.YEAR_OF_ERA) != parsedDate.get(ChronoField.YEAR_OF_ERA)) {
+                return false;
+            }
+        }
+        if (parseResult.isSupported(ChronoField.DAY_OF_MONTH)) {
+            if (parseResult.get(ChronoField.DAY_OF_MONTH) != parsedDate.get(ChronoField.DAY_OF_MONTH)) {
+                return false;
+            }
+        }
+        if (parseResult.isSupported(ChronoField.ERA)) {
+            if (parseResult.get(ChronoField.ERA) != parsedDate.get(ChronoField.ERA)) {
+                return false;
+            }
+        }
+
+      return true;
     }
 
     /**
@@ -198,11 +188,11 @@ public class InternalUtilities {
         Insets insets;
         if (windowOrNull == null) {
             insets = Toolkit.getDefaultToolkit().getScreenInsets(GraphicsEnvironment
-                    .getLocalGraphicsEnvironment().getDefaultScreenDevice()
-                    .getDefaultConfiguration());
+                .getLocalGraphicsEnvironment().getDefaultScreenDevice()
+                .getDefaultConfiguration());
         } else {
             insets = windowOrNull.getToolkit().getScreenInsets(
-                    windowOrNull.getGraphicsConfiguration());
+                windowOrNull.getGraphicsConfiguration());
         }
         return insets;
     }
@@ -237,7 +227,7 @@ public class InternalUtilities {
         if (windowOrNull == null) {
             GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
             insets = Toolkit.getDefaultToolkit().getScreenInsets(ge.getDefaultScreenDevice()
-                    .getDefaultConfiguration());
+                .getDefaultConfiguration());
             bounds = ge.getDefaultScreenDevice().getDefaultConfiguration().getBounds();
         } else {
             GraphicsConfiguration gc = windowOrNull.getGraphicsConfiguration();
@@ -251,22 +241,6 @@ public class InternalUtilities {
         return bounds;
     }
 
-    /**
-     * forceNumberStringToTwoDigits, This takes a string of digits, and forces it to be two digits
-     * long. First any extra leftmost digits are truncated, leaving only the right one digit or
-     * right two digits. If there is only one digit, it is zero padded to enforce a two digit string
-     * result. This function is used by the DatePickerUtilities.doesParsedDateMatchText() function.
-     */
-    private static String forceNumberStringToTwoDigits(String text) {
-        while (text.length() < 2) {
-            text = "0" + text;
-        }
-        if (text.length() > 2) {
-            text = text.substring(text.length() - 2, text.length());
-        }
-        return text;
-    }
-
     /**
      * generateDefaultFormatterCE, This returns a default formatter for the specified locale, that
      * can be used for displaying or parsing AD dates. The formatter is generated from the default
@@ -274,14 +248,14 @@ public class InternalUtilities {
      */
     public static DateTimeFormatter generateDefaultFormatterCE(Locale pickerLocale) {
         DateTimeFormatter formatCE = new DateTimeFormatterBuilder().parseLenient().
-                parseCaseInsensitive().appendLocalized(FormatStyle.LONG, null).
-                toFormatter(pickerLocale);
+            parseCaseInsensitive().appendLocalized(FormatStyle.LONG, null).
+            toFormatter(pickerLocale);
         // Get the local language as a string.
         String language = pickerLocale.getLanguage();
         // Override the format for the turkish locale to remove the name of the weekday.
         if ("tr".equals(language)) {
             formatCE = PickerUtilities.createFormatterFromPatternString(
-                    "dd MMMM yyyy", pickerLocale);
+                "dd MMMM yyyy", pickerLocale);
         }
         // Return the generated format.
         return formatCE;
@@ -297,20 +271,20 @@ public class InternalUtilities {
         // This is verified to work for the following locale languages:
         // en, de, fr, pt, ru, it, nl, es, pl, da, ro, sv, zh.
         String displayFormatterBCPattern = DateTimeFormatterBuilder.getLocalizedDateTimePattern(
-                FormatStyle.LONG, null, IsoChronology.INSTANCE, pickerLocale);
+            FormatStyle.LONG, null, IsoChronology.INSTANCE, pickerLocale);
         displayFormatterBCPattern = displayFormatterBCPattern.replace("y", "u");
         // Note: We could have used DateUtilities.createFormatterFromPatternString(), which should
         // have the same formatter options as this line. We kept this code independent in case
         // anyone ever mistakenly changes that utility function.
         DateTimeFormatter displayFormatterBC = new DateTimeFormatterBuilder().parseLenient()
-                .parseCaseInsensitive().appendPattern(displayFormatterBCPattern)
-                .toFormatter(pickerLocale);
+            .parseCaseInsensitive().appendPattern(displayFormatterBCPattern)
+            .toFormatter(pickerLocale);
         // Get the local language as a string.
         String language = pickerLocale.getLanguage();
         // Override the format for the turkish locale to remove the name of the weekday.
         if ("tr".equals(language)) {
             displayFormatterBC = PickerUtilities.createFormatterFromPatternString(
-                    "dd MMMM uuuu", pickerLocale);
+                "dd MMMM uuuu", pickerLocale);
         }
         return displayFormatterBC;
     }
@@ -327,17 +301,19 @@ public class InternalUtilities {
      * kinds of mistakes. If the parsed text does not match the day of the month (and year) of the
      * parsed date, then this function will return null.
      */
-    static public LocalDate getParsedDateOrNull(String text, DateTimeFormatter displayFormatterAD,
-            DateTimeFormatter displayFormatterBC, ArrayList<DateTimeFormatter> parsingFormatters,
-            Locale formatLocale) {
+    static public LocalDate getParsedDateOrNull(String text,
+        DateTimeFormatter displayFormatterAD, DateTimeFormatter displayFormatterBC, 
+        ArrayList<DateTimeFormatter> parsingFormatters) {
         if (text == null || text.trim().isEmpty()) {
             return null;
         }
-        text = text.trim().toLowerCase();
+        text = text.trim();
+        DateTimeFormatter usedFormatter = null;
         LocalDate parsedDate = null;
         if (parsedDate == null) {
             try {
                 parsedDate = LocalDate.parse(text, displayFormatterAD);
+                usedFormatter = displayFormatterAD;
             } catch (Exception ex) {
             }
         }
@@ -345,27 +321,29 @@ public class InternalUtilities {
             try {
                 // Note: each parse attempt must have its own try/catch block.
                 parsedDate = LocalDate.parse(text, displayFormatterBC);
+                usedFormatter = displayFormatterBC;
             } catch (Exception ex) {
             }
         }
         for (int i = 0; ((parsedDate == null) && (i < parsingFormatters.size())); ++i) {
             try {
                 parsedDate = LocalDate.parse(text, parsingFormatters.get(i));
+                usedFormatter = parsingFormatters.get(i);
             } catch (Exception ex) {
             }
         }
         // Check for any "successfully" parsed but nonexistent dates like Feb 31.
         // Note, this function has been thoroughly tested. See the function docs for details.
         if ((parsedDate != null) && (!InternalUtilities.doesParsedDateMatchText(
-                parsedDate, text, formatLocale))) {
+                parsedDate, text, usedFormatter))) {
             return null;
         }
         return parsedDate;
     }
 
     public static LocalTime getParsedTimeOrNull(String timeText,
-            DateTimeFormatter formatForDisplayTime, DateTimeFormatter formatForMenuTimes,
-            ArrayList<DateTimeFormatter> formatsForParsing, Locale timePickerLocale) {
+        DateTimeFormatter formatForDisplayTime, DateTimeFormatter formatForMenuTimes,
+        ArrayList<DateTimeFormatter> formatsForParsing, Locale timePickerLocale) {
         if (timeText == null || timeText.trim().isEmpty()) {
             return null;
         }
@@ -434,6 +412,12 @@ public class InternalUtilities {
      * otherwise returns false.
      */
     static public boolean isMouseWithinComponent(Component component) {
+        if (!component.isVisible()) {
+            // component.getLocationOnScreen() will throw an
+            // IllegalComponentStateException if the component
+            // is currently not visible
+            return false;
+        }
         Point mousePos = MouseInfo.getPointerInfo().getLocation();
         Rectangle bounds = component.getBounds();
         bounds.setLocation(component.getLocationOnScreen());
@@ -487,8 +471,8 @@ public class InternalUtilities {
      * InputStream input = getClass().getResourceAsStream("/classpath/to/my/file.class");
      */
     public static int getCompiledJavaVersionFromJavaClassFile(
-            InputStream classByteStream, boolean majorVersionRequested)
-            throws Exception {
+        InputStream classByteStream, boolean majorVersionRequested)
+        throws Exception {
         DataInputStream dataInputStream = new DataInputStream(classByteStream);
         // Skip the "magic number".
         dataInputStream.readInt();
@@ -508,7 +492,7 @@ public class InternalUtilities {
      * InputStream input = getClass().getResourceAsStream("/classpath/to/my/file.class");
      */
     public static String getCompiledJavaMajorVersionFromJavaClassFileAsString(
-            InputStream classByteStream) throws Exception {
+        InputStream classByteStream) throws Exception {
         int majorVersion = getCompiledJavaVersionFromJavaClassFile(classByteStream, true);
         switch (majorVersion) {
             case 50:
